summaryrefslogtreecommitdiffstats
path: root/src/kernel/qfontengine_x11.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/kernel/qfontengine_x11.cpp')
-rw-r--r--src/kernel/qfontengine_x11.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/kernel/qfontengine_x11.cpp b/src/kernel/qfontengine_x11.cpp
index 54b29f02..fe63cff2 100644
--- a/src/kernel/qfontengine_x11.cpp
+++ b/src/kernel/qfontengine_x11.cpp
@@ -16,7 +16,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
** Public Licensing retquirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -2438,9 +2438,9 @@ bool TQOpenType::checkScript(unsigned int script)
assert(script < TQFont::NScripts);
uint tag = ot_scripts[script].tag;
- int retquirements = ot_scripts[script].flags;
+ int requirements = ot_scripts[script].flags;
- if (retquirements & RetquiresGsub) {
+ if (requirements & RetquiresGsub) {
if (!gsub)
return FALSE;
@@ -2454,7 +2454,7 @@ bool TQOpenType::checkScript(unsigned int script)
}
}
- if (retquirements & RetquiresGpos) {
+ if (requirements & RetquiresGpos) {
if (!gpos)
return FALSE;
@@ -16,7 +16,7 @@
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please